@@ -23,31 +23,17 @@
 
 #include <stdlib.h>
 #include <unistd.h>
-#include <signal.h>
-#include <errno.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <time.h>
 #include <wait.h>
-#include <unistd.h>
 
 #include <qlayout.h>
-#include <qvbox.h>
-#include <qiconset.h> 
-#include <qsizepolicy.h> 
-#include <qevent.h>
 
-#include <kapplication.h>
-#include <kglobal.h>
-#include <klocale.h>
+#include "kpanelapplet.h"
 #include <kiconloader.h>
-#include <krun.h>
+#include <klocale.h>
 #include <kglobalsettings.h>
 #include <kmessagebox.h>
 #include <kaboutapplication.h>
-#include <kstandarddirs.h>
 #include <kpopupmenu.h>
-#include <kdebug.h>
 
 #include "statusbutton.h"
 #include "light.h"
@@ -55,7 +41,6 @@
 #include "speciallabels.h"
 #include "modem.h"
 #include "kmodemlightsdlg.h"
-#include "kmodemlights.h"
 #include "kmodemlights.moc"
 
 extern "C" {
@@ -347,7 +332,7 @@ void KModemLightsApplet::timerEvent(QTimerEvent *)
 	  modemWasOn = true;
 	}
 	
-	updateGraph(rx-graphRx, tx-graphTx);
+	updateGraph((rx-graphRx)/2, (tx-graphTx)/2); // 2sec!
 	graphRx = rx;
 	graphTx = tx;
       }
@@ -410,14 +395,20 @@ void  KModemLightsApplet::updateTimer()
 
 void KModemLightsApplet::dial()
 {
+  int ans = KMessageBox::Yes;
+  
   if (modem.isConnected()) {
-    int ans = KMessageBox::questionYesNo(this, 
-					 i18n("You are currently connected.\n"
-					      "Do you want to disconnect?"));
+    if (showRequesters) {
+      ans = KMessageBox::questionYesNo(this, 
+				       i18n("You are currently connected.\n"
+					    "Do you want to disconnect?"));
+    }
     if (ans == KMessageBox::Yes)
       system_nowait(disconnectCommand.ascii());
   } else {
-    int ans = KMessageBox::questionYesNo(this, i18n("Do you want to connect?"));
+    if (showRequesters) {
+      ans = KMessageBox::questionYesNo(this, i18n("Do you want to connect?"));
+    }
     if (ans == KMessageBox::Yes)
       system_nowait(connectCommand.ascii());
   }
@@ -452,15 +443,21 @@ void KModemLightsApplet::about()
 
 void KModemLightsApplet::preferences()
 {
-  KModemLightsDlg dlg(this, "moondlg", this);
+  KModemLightsDlg dlg(this);
   if (dlg.exec() == KModemLightsDlg::Accepted) {
-    // "write" config
     config()->setGroup("General");
+
+    // "write" device
     config()->writePathEntry("Lockfile", dlg.lockFile());
     config()->writeEntry("Devicename",  dlg.deviceName());
     config()->writeEntry("Connect", dlg.connectCommand());
     config()->writeEntry("Disconnect", dlg.disconnectCommand());
+
+    // write general
     config()->writeEntry("Update frequency", dlg.updateFrequency());
+    config()->writeEntry("Show requesters", dlg.showRequesters());
+    config()->writeEntry("Graph automax", dlg.graphAutoMax());
+    config()->writeEntry("Graph maxvalue", dlg.graphMaxValue());
 
     // "write" colors
     config()->writeEntry("Rx on color", dlg.rxOnColor());
@@ -469,6 +466,7 @@ void KModemLightsApplet::preferences()
     config()->writeEntry("Tx on color", dlg.txOnColor());
     config()->writeEntry("Tx off color", dlg.txOffColor());
     config()->writeEntry("Tx graph color", dlg.txGraphColor());
+    config()->writeEntry("Graph background", dlg.graphBgColor());
     config()->writeEntry("Await color", dlg.statusAwaitColor());
     config()->writeEntry("On color", dlg.statusOnColor());
     config()->sync();
@@ -481,16 +479,22 @@ void KModemLightsApplet::readConfig()
 {
   config()->setGroup("General");
 
-  // read config
-  connectCommand = config()->readEntry("Connect", "pon");
-  disconnectCommand = config()->readEntry("Disconnect", "poff");
-  updateFrequency = config()->readNumEntry("Update frequency", 5);
-
-  // read modem config
+  // read device
   QString lockFile = config()->readPathEntry("Lockfile", "/var/lock/LCK..ttyS1");
   modem.setLockFile(lockFile.ascii());
   QString deviceName = config()->readEntry("Devicename", "ppp0");
   modem.setDeviceName(deviceName.ascii());
+  connectCommand = config()->readEntry("Connect", "pon");
+  disconnectCommand = config()->readEntry("Disconnect", "poff");
+
+  // read general
+  updateFrequency = config()->readNumEntry("Update frequency", 5);
+  showRequesters = config()->readBoolEntry("Show requesters", true);
+  graphMaxValue = config()->readNumEntry("Graph maxvalue", 10000);
+  bool graphAutoMax = config()->readBoolEntry("Graph automax", true);
+  if (graphAutoMax) graph->unsetMaxValue();
+  else
+    graph->setMaxValue(graphMaxValue);
 
   // default colors
   static const QColor CGreen(0x00FF00);
@@ -506,11 +510,13 @@ void KModemLightsApplet::readConfig()
   lightTx->setColors(config()->readColorEntry("Tx on color", &CRed),
 		     config()->readColorEntry("Tx off color", &CDarkRed));
 
-  graph->setColors(config()->readColorEntry("Rx graph color", &CGreen),
-		   config()->readColorEntry("Tx graph color", &CRed));
+  graph->setColorA(config()->readColorEntry("Rx graph color", &CGreen));
+  graph->setColorB(config()->readColorEntry("Tx graph color", &CRed));
+  graph->setColorBg(config()->readColorEntry("Graph background", &Qt::black));
   
   button->setColor(StatusButton::Wait,
 		   config()->readColorEntry("Await color", &CYellow));
   button->setColor(StatusButton::On,
 		   config()->readColorEntry("On color", &CGreen));
+
 }
