@@ -20,28 +20,29 @@
 
 #include <qspinbox.h>
 #include <qlayout.h>
-#include <qgrid.h>
 #include <qwhatsthis.h>
-#include <qpushbutton.h>
 #include <qlineedit.h> 
 #include <qgroupbox.h>
+#include <qvgroupbox.h>
+#include <qcheckbox.h>
+#include <qhbox.h>
+#include <qgrid.h>
 
 #include <klocale.h>
 #include <kapplication.h>
 #include <ktabwidget.h>
 #include <kpushbutton.h>
-#include <kfontdialog.h>
-//
-#include <kcolorbutton.h> 
+#include <kcolorbutton.h>
 
 #include "kmodemlights.h"
 #include "light.h"
 #include "graph.h"
 #include "statusbutton.h"
+
 #include "kmodemlightsdlg.moc"
 
-KModemLightsDlg::KModemLightsDlg(QWidget *parent, const char *name,
-				 KModemLightsApplet *ap)
+KModemLightsDlg::KModemLightsDlg(KModemLightsApplet *ap, QWidget *parent, 
+				 const char *name)
   : KDialogBase(parent, name, true, i18n("Change Settings"),
 		Ok|Cancel|Help),
     applet(ap)
@@ -50,7 +51,8 @@ KModemLightsDlg::KModemLightsDlg(QWidget *parent, const char *name,
   page->setMargin(marginHint());
   setMainWidget(page);
 
-  page->addTab(generateDevice(), i18n("Devicesettings"));
+  page->addTab(generateGeneral(), i18n("Behaviour"));
+  page->addTab(generateDevice(), i18n("Device"));
   page->addTab(generateColor(), i18n("Colors"));
 
   connect(this, SIGNAL(helpClicked()), SLOT(help()));
@@ -59,61 +61,49 @@ KModemLightsDlg::KModemLightsDlg(QWidget *parent, const char *name,
 QWidget *KModemLightsDlg::generateDevice()
 {
   QWidget *tab = new QWidget();
-  QVBoxLayout *vbox = new QVBoxLayout(tab);
-  QGrid *grid = new QGrid(2, tab);
-  grid->setSpacing(spacingHint());
-  vbox->add(grid);
+  QVBoxLayout *vbox = new QVBoxLayout(tab, 0, spacingHint());
 
-  // Frequency
-  QLabel *label = new QLabel(i18n("Update Frequency:"), grid, "caption" );
-  frequencyWidget = new QSpinBox(1, 5, 1, grid);
-  frequencyWidget->setValue(applet->updateFrequency);
-  frequencyWidget->setSuffix(" Hz");
-  QString text = i18n("<b>This is the frequency the applet is updated.</b>"
-		      "<p>A value of 3 means it is updated 3 times a second."
-		      "The default value is 5. On extremly slow systems "
-		      "you might like to reduce the frequency to lower "
-		      "the system-load, mostly the default is O.K.</p>");
-  QWhatsThis::add(label, text);
-  QWhatsThis::add(frequencyWidget, text);
+  QGrid *group = new QGrid(2, tab);
+  group->setSpacing(spacingHint());
+  vbox->addWidget(group);
 
   // Device Name
-  label = new QLabel(i18n("Device:"), grid);
-  text = i18n("<b>This is the name of the device.</b>"
+  QLabel *label = new QLabel(i18n("Device:"), group);
+  QString text = i18n("<b>This is the name of the device.</b>"
 	      "<p>P.e. 'ppp0' for (the first) PPP device.</p>");
   QWhatsThis::add(label, text);  
-  deviceWidget = new QLineEdit(applet->modem.deviceName(), grid);
+  deviceWidget = new QLineEdit(applet->modem.deviceName(), group);
   QWhatsThis::add(deviceWidget, text);
   
   // Lockfile Name
-  label = new QLabel(i18n("Lockfile:"), grid);
+  label = new QLabel(i18n("Lockfile:"), group);
   text = i18n("<b>This is the path to the file, that is used to lock"
 	      "the device.</b>"
 	      "<p>On a standard linux-system this is "
 	      "<nobr>'/var/lock/LCK..ttyS1'</nobr> for a modem "
 	      "on <nobr>'/dev/ttyS1'</nobr>.</p>");
   QWhatsThis::add(label, text);
-  lockFileWidget = new QLineEdit(applet->modem.lockFile(), grid);
+  lockFileWidget = new QLineEdit(applet->modem.lockFile(), group);
   QWhatsThis::add(lockFileWidget, text);
 
   // Connect command
-  label = new QLabel(i18n("Connect:"), grid);
+  label = new QLabel(i18n("Connect:"), group);
   text = i18n("<b>This is the command that is executed to go online.</b>"
 	      "<p>It is different on different distributions and systems.</p>" 
 	      "<p>For a connection configured with kppp it is "
 	      "<nobr>'kppp -c &lt;provider&gt;'</nobr>.</p>");
   QWhatsThis::add(label, text);
-  connectWidget = new QLineEdit(applet->connectCommand, grid);
+  connectWidget = new QLineEdit(applet->connectCommand, group);
   QWhatsThis::add(connectWidget, text);
 
   // Disonnect command
-  label = new QLabel(i18n("Disconnect:"), grid);
+  label = new QLabel(i18n("Disconnect:"), group);
   text = i18n("<b>This is the command that is executed to go offline.</b>"
 	      "<p>It is different on different distributions and systems.</p>"
 	      "<p>For a connection configured with kppp it is "
 	      "<nobr>'kppp -k -q'<nobr>.</p>");
   QWhatsThis::add(label, text);
-  disconnectWidget = new QLineEdit(applet->disconnectCommand, grid);
+  disconnectWidget = new QLineEdit(applet->disconnectCommand, group);
   QWhatsThis::add(disconnectWidget, text);
 
   // Hint to use What's this help
@@ -126,10 +116,90 @@ QWidget *KModemLightsDlg::generateDevice()
   return tab;
 }
 
-static QLabel *newCaption(QString s, QWidget *w)
+QWidget *KModemLightsDlg::generateGeneral()
+{
+  QWidget *tab = new QWidget();
+  QVBoxLayout *vbox = new QVBoxLayout(tab, 0, spacingHint());
+
+  // **** Behaviour
+  QVGroupBox *group = new QVGroupBox(i18n("General"), tab);
+  vbox->addWidget(group);
+ 
+  // Frequency
+  QHBox *hb = new QHBox(group);
+  hb->setSpacing(spacingHint());
+  QLabel *label = new QLabel(i18n("Update Frequency:"), hb);
+  frequencyWidget = new QSpinBox(1, 5, 1, hb);
+  frequencyWidget->setValue(applet->updateFrequency);
+  frequencyWidget->setSuffix(" Hz");
+  QString text = i18n("<b>This is the frequency the applet is updated.</b>"
+	      "<p>A value of 3 means it is updated 3 times a second."
+	      "The default value is 5. On extremly slow systems "
+	      "you might like to reduce the frequency to lower "
+	      "the system-load, mostly the default is O.K.</p>");
+  QWhatsThis::add(label, text);
+  QWhatsThis::add(frequencyWidget, text);
+
+  // Requesters
+  showRequestersWidget = new QCheckBox(i18n("checkback on going on-/offline"), group);
+  showRequestersWidget->setChecked(applet->showRequesters);
+  text = i18n("<b>Checkback-requester</b>"
+	      "<p>Check this box if you don't want a checkback-requester shown "
+	      "when you request going on- or offline.</p>");
+  QWhatsThis::add(showRequestersWidget, text);
+
+  // **** Graph
+  group = new QVGroupBox(i18n("Graph"), tab);
+  vbox->addWidget(group);
+ 
+  // Auto range
+  autoMaxWidget = new QCheckBox(i18n("Automatic range detection"), group);
+  autoMaxWidget->setChecked(applet->graph->autoMax());
+  text = i18n("<b>self-adjusting y-range on graph</b>"
+	      "<p>Check this box if you want the display range to adapt "
+	      "dynamically to the currently displayed values. If you don't "
+	      "check this, you have to specify the range you want in the "
+	      "field below.</p>");
+  QWhatsThis::add(autoMaxWidget, text);
+
+  // MaxValue
+  hb = new QHBox(group);
+  hb->setSpacing(spacingHint());
+  label = new QLabel(i18n("Maximum value:"), hb);
+  maxValueWidget = new QLineEdit(QString().setNum(applet->graphMaxValue), hb);
+  maxValueWidget->setAlignment(Qt::AlignRight);
+  text = i18n("<b>This is the maximum Value of the Graph</b>"
+	      "<p>if automatic setting is switched off this determines"
+	      "the maximum value the graph can display.</p>");
+  QWhatsThis::add(label, text);
+  QWhatsThis::add(frequencyWidget, text);
+
+  // signals
+  maxValueWidget->setDisabled(autoMaxWidget->isChecked());
+  connect(autoMaxWidget, SIGNAL(toggled(bool)), 
+	  maxValueWidget, SLOT(setDisabled(bool)));
+
+  // Hint to use What's this help
+  vbox->addStretch();
+  label = new QLabel(i18n("<i>There is help available for all fields on this "
+			  "tab, that can be shown with Shift-F1.</i>"), tab);
+  label->setTextFormat(Qt::RichText); // does not break the text otherwise
+  vbox->addWidget(label);
+
+  return tab;
+}
+
+QLabel *KModemLightsDlg::newCaption(const QString &s, QWidget *w)
 {
   QLabel *l = new QLabel(s, w);
   l->setAlignment(Qt::AlignHCenter|Qt::AlignVCenter);
+#if 0
+  QFont f = font();
+  if(f.pointSize()) {
+    f.setPointSize(f.pointSize()*0.9);
+    l->setFont(f);
+  }
+#endif
 
   return l;
 }
@@ -137,26 +207,19 @@ static QLabel *newCaption(QString s, QWidget *w)
 QWidget *KModemLightsDlg::generateColor()
 {
   QWidget *tab = new QWidget();
-  QVBoxLayout *vbox = new QVBoxLayout(tab);
-  vbox->setSpacing(spacingHint());
+  QVBoxLayout *vbox = new QVBoxLayout(tab, 0, spacingHint());
 
-  QGroupBox *group = new QGroupBox(2, Qt::Vertical, i18n("Receive Data"), tab);
+  QGroupBox *group = new QGroupBox(3, Qt::Vertical, i18n("LEDs"), tab);
   vbox->add(group);
-  rxOn = new KColorButton(group);
-  QLabel *label = newCaption(i18n("On"), group);
-  rxOff = new KColorButton(group);
-  label = newCaption(i18n("Off"), group);
-  rxGraph = new KColorButton(group);
-  label = newCaption(i18n("Graph"), group);
-
-  group = new QGroupBox(2, Qt::Vertical, i18n("Send Data"), tab);
-  vbox->add(group);
-  txOn = new KColorButton(group);
+  group->addSpace(0);
+  QLabel *label = new QLabel(i18n("Receive Data:"), group);
+  label = new QLabel(i18n("Send Data:"), group);
   label = newCaption(i18n("On"), group);
-  txOff = new KColorButton(group);
+  rxOn = new KColorButton(group);
+  txOn = new KColorButton(group);
   label = newCaption(i18n("Off"), group);
-  txGraph = new KColorButton(group);
-  label = newCaption(i18n("Graph"), group);
+  rxOff = new KColorButton(group);
+  txOff = new KColorButton(group);
 
   group = new QGroupBox(2, Qt::Vertical, i18n("Connection Status"), tab);
   vbox->add(group);
@@ -165,6 +228,15 @@ QWidget *KModemLightsDlg::generateColor()
   statusOn = new KColorButton(group);
   label = newCaption(i18n("Connected"), group);
 
+  group = new QGroupBox(2, Qt::Vertical, i18n("Graph"), tab);
+  vbox->add(group);
+  rxGraph = new KColorButton(group);
+  label = newCaption(i18n("Receive"), group);
+  txGraph = new KColorButton(group);
+  label = newCaption(i18n("Send"), group);
+  graphBg = new KColorButton(group);
+  label = newCaption(i18n("Background"), group);
+
   vbox->addStretch();  
 
   // setup colors in widgets
@@ -176,6 +248,8 @@ QWidget *KModemLightsDlg::generateColor()
   txOff->setColor(applet->lightTx->getColorOff());
   txGraph->setColor(applet->graph->getColorB());
 
+  graphBg->setColor(applet->graph->getColorBg());
+
   statusAwait->setColor(applet->button->getColor(StatusButton::Wait));
   statusOn->setColor(applet->button->getColor(StatusButton::On));
 
