@@ -38,13 +38,13 @@ class StatusButton : public QPushButton
   Status status() const { return myStatus; };
 
   void setColor(const Status s, const QColor &c);
-  QColor getColor(const Status s);
+  QColor getColor(const Status s) const;
 
  public slots:
 
  private:
 
-  void generateIcon(QPixmap &px, QPixmap &sign, QColor &col);
+  void generateIcon(QPixmap &px, const QPixmap &sign, const QColor &col);
 
   QPixmap on, off, wait;
   QPixmap signOn, signOff, signWait, signMask;
